@@ -26,12 +26,7 @@
 #include <libwnck/libwnck.h>
 #include <string.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 #include <gtksourceview/gtksource.h>
-#else
-#include <gtksourceview/gtksourceview.h>
-#include <gtksourceview/gtksourcebuffer.h>
-#endif
 
 #include "stickynotes.h"
 #include "stickynotes_callbacks.h"
@@ -40,6 +35,7 @@
 
 /* Stop gcc complaining about xmlChar's signedness */
 #define XML_CHAR(str) ((xmlChar *) (str))
+#define STICKYNOTES_ICON_SIZE 8
 
 static gboolean save_scheduled = FALSE;
 
@@ -104,7 +100,6 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 {
 	StickyNote *note;
 	GtkBuilder *builder;
-	GtkIconSize size;
 
 	note = g_new (StickyNote, 1);
 
@@ -197,13 +192,15 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 				note->y);
 
 	/* Set the button images */
-	size = gtk_icon_size_from_name ("stickynotes_icon_size");
-	gtk_image_set_from_stock (note->img_close,
-			STICKYNOTES_STOCK_CLOSE, size);
-	gtk_image_set_from_stock (note->img_resize_se,
-			STICKYNOTES_STOCK_RESIZE_SE, size);
-	gtk_image_set_from_stock (note->img_resize_sw,
-			STICKYNOTES_STOCK_RESIZE_SW, size);
+	gtk_image_set_from_icon_name (note->img_close, STICKYNOTES_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+	gtk_image_set_pixel_size (note->img_close, STICKYNOTES_ICON_SIZE);
+
+	gtk_image_set_from_icon_name (note->img_resize_se, STICKYNOTES_STOCK_RESIZE_SE, GTK_ICON_SIZE_MENU);
+	gtk_image_set_pixel_size (note->img_resize_se, STICKYNOTES_ICON_SIZE);
+
+	gtk_image_set_from_icon_name (note->img_resize_sw, STICKYNOTES_STOCK_RESIZE_SW, GTK_ICON_SIZE_MENU);
+	gtk_image_set_pixel_size (note->img_resize_sw, STICKYNOTES_ICON_SIZE);
+
 	gtk_widget_show(note->w_lock);
 	gtk_widget_show(note->w_close);
 	gtk_widget_show(GTK_WIDGET (gtk_builder_get_object (builder, "resize_bar")));
@@ -257,8 +254,6 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 
 	g_signal_connect (G_OBJECT (note->w_window), "button-press-event",
 			G_CALLBACK (stickynote_move_cb), note);
-	g_signal_connect (G_OBJECT (note->w_window), "expose-event",
-			G_CALLBACK (stickynote_expose_cb), note);
 	g_signal_connect (G_OBJECT (note->w_window), "configure-event",
 			G_CALLBACK (stickynote_configure_cb), note);
 	g_signal_connect (G_OBJECT (note->w_window), "delete-event",
@@ -343,15 +338,9 @@ void stickynote_change_properties (StickyNote *note)
 
 	if (color_str)
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		GdkRGBA color;
 		gdk_rgba_parse (&color, color_str);
-		gtk_color_button_set_rgba (GTK_COLOR_BUTTON (note->w_color), &color);
-#else
-		GdkColor color;
-		gdk_color_parse (color_str, &color);
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_color), &color);
-#endif
+		gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (note->w_color), &color);
 		g_free (color_str);
 	}
 
@@ -364,15 +353,9 @@ void stickynote_change_properties (StickyNote *note)
 
 	if (color_str)
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		GdkRGBA font_color;
 		gdk_rgba_parse (&font_color, color_str);
-		gtk_color_button_set_rgba (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
-#else
-		GdkColor font_color;
-		gdk_color_parse (color_str, &font_color);
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
-#endif
+		gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (note->w_font_color), &font_color);
 		g_free (color_str);
 	}
 
@@ -439,7 +422,6 @@ stickynote_set_color (StickyNote  *note,
 {
 	char *color_str_actual, *font_color_str_actual;
 	gboolean force_default, use_system_color;
-	GtkRcStyle *rc_style;
 
 	if (save) {
 		if (note->color)
@@ -487,108 +469,47 @@ stickynote_set_color (StickyNote  *note,
 	else
 		font_color_str_actual = g_strdup (font_color_str);
 
-	rc_style = gtk_widget_get_modifier_style (note->w_window);
-
 	/* Do not use custom colors if "use_system_color" is enabled */
 	if (color_str_actual) {
-#if GTK_CHECK_VERSION (3, 0, 0)
-		GdkRGBA color;
-		gdk_rgba_parse (&color, color_str_actual);
-#endif
-		/* Make 4 shades of the color, getting darker from the
-		 * original, plus black and white */
-		GdkColor colors[6];
+		GdkRGBA colors[4];
 		gint i;
 
 		for (i = 0; i <= 3; i++)
 		{
-			gdk_color_parse (color_str_actual, &colors[i]);
-#if GTK_CHECK_VERSION (3, 0, 0)
-			colors[i].red = (color.red * (10 - i)) / 10;
-			colors[i].green = (color.green * (10 - i)) / 10;
-			colors[i].blue = (color.blue * (10 - i)) / 10;
-#else
+			gdk_rgba_parse (&colors[i], color_str_actual);
 			colors[i].red = (colors[i].red * (10 - i)) / 10;
 			colors[i].green = (colors[i].green * (10 - i)) / 10;
 			colors[i].blue = (colors[i].blue * (10 - i)) / 10;
-#endif
 		}
 
-		gdk_color_parse ("black", &colors[4]);
-		gdk_color_parse ("white", &colors[5]);
-
-#if !GTK_CHECK_VERSION (3, 0, 0)
-		gboolean success[6];
-
-		/* Allocate these colors */
-		gdk_colormap_alloc_colors (gtk_widget_get_colormap (note->w_window),
-		                           colors, 6, FALSE, TRUE, success);
-#endif
-		/* Apply colors to style */
-		rc_style->base[GTK_STATE_NORMAL] = colors[0];
-		rc_style->bg[GTK_STATE_PRELIGHT] = colors[1];
-		rc_style->bg[GTK_STATE_NORMAL] = colors[2];
-		rc_style->bg[GTK_STATE_ACTIVE] = colors[3];
-
-		rc_style->color_flags[GTK_STATE_PRELIGHT] = GTK_RC_BG;
-		rc_style->color_flags[GTK_STATE_NORMAL] =
-			GTK_RC_BG | GTK_RC_BASE;
-		rc_style->color_flags[GTK_STATE_ACTIVE] = GTK_RC_BG;
+		gtk_widget_override_background_color (note->w_window, GTK_STATE_NORMAL, &colors[0]);
+		gtk_widget_override_background_color (note->w_body, GTK_STATE_NORMAL, &colors[0]);
+		gtk_widget_override_background_color (note->w_lock, GTK_STATE_NORMAL, &colors[0]);
+		gtk_widget_override_background_color (note->w_close, GTK_STATE_NORMAL, &colors[0]);
+		gtk_widget_override_background_color (note->w_resize_se, GTK_STATE_NORMAL, &colors[0]);
+		gtk_widget_override_background_color (note->w_resize_sw, GTK_STATE_NORMAL, &colors[0]);
+	} else {
+		gtk_widget_override_background_color (note->w_window, GTK_STATE_NORMAL, NULL);
+		gtk_widget_override_background_color (note->w_body, GTK_STATE_NORMAL, NULL);
+		gtk_widget_override_background_color (note->w_lock, GTK_STATE_NORMAL, NULL);
+		gtk_widget_override_background_color (note->w_close, GTK_STATE_NORMAL, NULL);
+		gtk_widget_override_background_color (note->w_resize_se, GTK_STATE_NORMAL, NULL);
+		gtk_widget_override_background_color (note->w_resize_sw, GTK_STATE_NORMAL, NULL);
 	}
-	else {
-		rc_style->color_flags[GTK_STATE_PRELIGHT] = 0;
-		rc_style->color_flags[GTK_STATE_NORMAL] = 0;
-		rc_style->color_flags[GTK_STATE_ACTIVE] = 0;
-	}
-
-	g_object_ref (G_OBJECT (rc_style));
-
-	/* Apply the style to the widgets */
-	gtk_widget_modify_style (note->w_window, rc_style);
-	/* We shouldn't change the title font
-	 * gtk_widget_modify_style(note->w_title, rc_style); */
-	gtk_widget_modify_style (note->w_body, rc_style);
-	gtk_widget_modify_style (note->w_lock, rc_style);
-	gtk_widget_modify_style (note->w_close, rc_style);
-	gtk_widget_modify_style (note->w_resize_se, rc_style);
-	gtk_widget_modify_style (note->w_resize_sw, rc_style);
-
-	g_object_unref (G_OBJECT (rc_style));
 
 	if (font_color_str_actual)
 	{
-		GdkColor font_color;
-
-#if GTK_CHECK_VERSION (3, 0, 0)
 		GdkRGBA color;
 
 		gdk_rgba_parse (&color, font_color_str_actual);
-		font_color.red = color.red;
-		font_color.green = color.green;
-		font_color.blue = color.blue;
-#else
-		gdk_color_parse (font_color_str_actual, &font_color);
-#endif
 
-		gtk_widget_modify_text (note->w_window,
-				GTK_STATE_NORMAL, &font_color);
-		gtk_widget_modify_text (note->w_window,
-				GTK_STATE_PRELIGHT, &font_color);
-		gtk_widget_modify_text (note->w_body,
-				GTK_STATE_NORMAL, &font_color);
-		gtk_widget_modify_text (note->w_body,
-				GTK_STATE_PRELIGHT, &font_color);
+		gtk_widget_override_color (note->w_window, GTK_STATE_NORMAL, &color);
+		gtk_widget_override_color (note->w_body, GTK_STATE_NORMAL, &color);
 	}
 	else
 	{
-		gtk_widget_modify_text (note->w_window,
-				GTK_STATE_NORMAL, NULL);
-		gtk_widget_modify_text (note->w_window,
-				GTK_STATE_PRELIGHT, NULL);
-		gtk_widget_modify_text (note->w_body,
-				GTK_STATE_NORMAL, NULL);
-		gtk_widget_modify_text (note->w_body,
-				GTK_STATE_PRELIGHT, NULL);
+		gtk_widget_override_color (note->w_window, GTK_STATE_NORMAL, NULL);
+		gtk_widget_override_color (note->w_body, GTK_STATE_NORMAL, NULL);
 	}
 
 	if (color_str_actual)
@@ -601,7 +522,7 @@ stickynote_set_color (StickyNote  *note,
 void
 stickynote_set_font (StickyNote *note, const gchar *font_str, gboolean save)
 {
-	GtkRcStyle *rc_style = gtk_widget_get_modifier_style(note->w_window);
+	PangoFontDescription *font_desc;
 	gchar *font_str_actual;
 
 	if (save) {
@@ -625,41 +546,38 @@ stickynote_set_font (StickyNote *note, const gchar *font_str, gboolean save)
 		font_str_actual = g_strdup (font_str);
 
 	/* Do not use custom fonts if "use_system_font" is enabled */
-	pango_font_description_free (rc_style->font_desc);
-	rc_style->font_desc = font_str_actual ?
+	font_desc = font_str_actual ?
 		pango_font_description_from_string (font_str_actual): NULL;
 
-	g_object_ref (G_OBJECT (rc_style));
 	/* Apply the style to the widgets */
-	gtk_widget_modify_style(note->w_window, rc_style);
-	gtk_widget_modify_style(note->w_body, rc_style);
+	gtk_widget_override_font (note->w_window, font_desc);
+	gtk_widget_override_font (note->w_body, font_desc);
 
 	g_free (font_str_actual);
-	g_object_unref (G_OBJECT(rc_style));
+	pango_font_description_free (font_desc);
 }
 
 /* Lock/Unlock a sticky note from editing */
 void stickynote_set_locked(StickyNote *note, gboolean locked)
 {
-	GtkIconSize size;
 	note->locked = locked;
 
 	/* Set cursor visibility and editability */
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(note->w_body), !locked);
 	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(note->w_body), !locked);
 
-	size = gtk_icon_size_from_name ("stickynotes_icon_size");
-
 	/* Show appropriate icon and tooltip */
 	if (locked) {
-		gtk_image_set_from_stock(note->img_lock, STICKYNOTES_STOCK_LOCKED, size);
+		gtk_image_set_from_icon_name (note->img_lock, STICKYNOTES_STOCK_LOCKED, GTK_ICON_SIZE_MENU);
 		gtk_widget_set_tooltip_text(note->w_lock, _("This note is locked."));
 	}
 	else {
-		gtk_image_set_from_stock(note->img_lock, STICKYNOTES_STOCK_UNLOCKED, size);
+		gtk_image_set_from_icon_name (note->img_lock, STICKYNOTES_STOCK_UNLOCKED, GTK_ICON_SIZE_MENU);
 		gtk_widget_set_tooltip_text(note->w_lock, _("This note is unlocked."));
 	}
 
+	gtk_image_set_pixel_size (note->img_lock, STICKYNOTES_ICON_SIZE);
+
 	gtk_toggle_action_set_active(note->ta_lock_toggle_item, locked);
 
 	stickynotes_applet_update_menus();
